@@ -162,6 +162,29 @@ def install_snapshot(path: Path):
 
     poolparty.install_snapshot(path)
 
+
+@pp.command()
+@click.option("--port", type=click.INT, default=5000, help="The port to run the server on [default: 5000]")
+def mock_server(port: int):
+    """Runs a mock server for testing and debugging external integrations
+
+    PoolParty provides several integrations with external APIs/services (cf.
+    Semantic Middleware Configurator). This command starts a mock server for
+    debugging/testing such integrations.
+
+    The port on which to run the server can be specified via --port. It defaults
+    to 5000.
+
+    # Webhook consumer
+    Starts a server and echoes any request (+ auxiliary information) coming in.
+    In addition starts a healthcheck endpoint that just always returns `200 OK`.
+
+    The webhook consumer url (to configure in Semantic Middleware Configurator)
+    is `http://localhost:5000/hook`.
+    """
+
+    poolparty.run_mock_server(port)
+
 @jk.command()
 @click.option("--branch", help="The branch to build")
 @click.option('--no-autodetect', type=click.BOOL, is_flag=True, default=False, help="Disable autodetection of branch in a git repository")
