@@ -2,6 +2,7 @@
 
 import os
 
+import json
 import requests
 from pathlib import Path
 from rich.progress import (
@@ -23,6 +24,10 @@ from cryptography.hazmat.primitives.padding import PKCS7
 
 from loguru import logger
 
+from flask import Flask, request
+from rich import print
+
+
 @logger.catch
 def encrypt(clear: str, password, salt, strength) -> str:
     logger.info("Initializing encryption algorithm")
@@ -113,4 +118,22 @@ def install_snapshot(path: Path):
                     progress.update(task_id, advance=len(chunk), refresh=True)
 
     download_path.chmod(0o500)
-    subprocess.call(f'/bin/env sh -c {download_path}')
+    subprocess.call(["/bin/env", "sh", "-c", f"{download_path}"])
+
+
+def run_mock_server(port):
+    app = Flask(__name__)
+
+    @app.post("/hook")
+    def webhook():
+        logger.info("Webhook triggered")
+        print(request)
+        print(request.headers)
+        print(json.loads(request.data))
+        return ""
+
+    @app.get("/hook")
+    def webhook_healthcheck():
+        return ""
+
+    app.run(debug=True, port=port)
